#
# K2HDKC DBaaS on Kubernetes Command Line Interface - K2HR3 CLI Plugin
#
# Copyright 2021 Yahoo Japan Corporation.
#
# K2HDKC DBaaS is a DataBase as a Service provided by Yahoo! JAPAN
# which is built K2HR3 as a backend and provides services in
# cooperation with Kubernetes.
# The Override configuration for K2HDKC DBaaS serves to connect the
# components that make up the K2HDKC DBaaS. K2HDKC, K2HR3, CHMPX,
# and K2HASH are components provided as AntPickax.
#
# For the full copyright and license information, please view
# the license file that was distributed with this source code.
#
# AUTHOR:   Takeshi Nakatani
# CREATE:   Wed Sep 15 2021
# REVISION:
#

#
# Local macros/define
#
%if %{undefined package_revision}
%global package_revision 1
%endif

%if %{undefined make_build}
%global make_build %{__make} %{?_smp_mflags}
%endif

%if %{undefined autosetup}
%global autosetup %setup -q
%endif

%global gittag v1.0.6

%if %{undefined make_check}
%global make_check 1
%endif

%if %{undefined not_run_autogen}
%global run_autogen ./autogen.sh
%else
%global run_autogen echo "skip autogen.sh"
%endif

#
# main package
#
Summary: K2HDKC DBaaS on Kubernetes CLI command
Name: k2hdkc-dbaas-k8s-cli
Version: 1.0.6
Release: %{package_revision}%{?dist}
License: MIT

URL: https://github.com/yahoojapan/k2hdkc-dbaas-k8s-cli
Source0: https://github.com/yahoojapan/k2hdkc-dbaas-k8s-cli/archive/%{gittag}/%{name}-%{version}.tar.gz
Requires: k2hr3-cli
BuildRequires: git-core make
BuildArch: noarch

%description
The K2HDKC DBaaS K8S CLI (Command Line Interface of Database
as a Service for K2HDKC) is a tool for building a K2HDKC
cluster in conjunction with K2HR3.
K2HDKC DBaaS K8S can build a dedicated K2HR3 system in a
Kubernetes cluster and build a K2HDKC cluster that works
with it.
With the basic components of Kubernetes system that works
with it, you can easily build a K2HDKC cluster on Kubernetes
cluster using the K2HDKC DBaaS K8S CLI.

%prep
%autosetup -n %{name}-%{version}

%build
%run_autogen
%configure --disable-static 
make build

%install
%make_install
install -D -m 444 src/libexec/database-k8s/CREDIT                                %{buildroot}/usr/libexec/k2hr3/database-k8s/CREDIT
install -D -m 444 src/libexec/database-k8s/VERSION                               %{buildroot}/usr/libexec/k2hr3/database-k8s/VERSION
install -D -m 444 src/libexec/database-k8s/certification.sh                      %{buildroot}/usr/libexec/k2hr3/database-k8s/certification.sh
install -D -m 444 src/libexec/database-k8s/command.sh                            %{buildroot}/usr/libexec/k2hr3/database-k8s/command.sh
install -D -m 444 src/libexec/database-k8s/functions.sh                          %{buildroot}/usr/libexec/k2hr3/database-k8s/functions.sh
install -D -m 444 src/libexec/database-k8s/help.sh                               %{buildroot}/usr/libexec/k2hr3/database-k8s/help.sh
install -D -m 444 src/libexec/database-k8s/options.sh                            %{buildroot}/usr/libexec/k2hr3/database-k8s/options.sh
install -D -m 444 src/libexec/database-k8s/summary.sh                            %{buildroot}/usr/libexec/k2hr3/database-k8s/summary.sh
install -D -m 444 src/libexec/database-k8s/variables.sh                          %{buildroot}/usr/libexec/k2hr3/database-k8s/variables.sh
install -D -m 444 src/libexec/database-k8s/k8sapi.sh                             %{buildroot}/usr/libexec/k2hr3/database-k8s/k8sapi.sh
install -D -m 444 src/libexec/database-k8s/configuration.sh                      %{buildroot}/usr/libexec/k2hr3/database-k8s/configuration.sh
install -D -m 444 src/libexec/database-k8s/constvariables.sh                     %{buildroot}/usr/libexec/k2hr3/database-k8s/constvariables.sh
install -D -m 444 src/libexec/database-k8s/dbaas-k8s.config                      %{buildroot}/usr/libexec/k2hr3/database-k8s/dbaas-k8s.config
install -D -m 444 src/libexec/database-k8s/k2hdkc.config                         %{buildroot}/usr/libexec/k2hr3/database-k8s/k2hdkc.config
install -D -m 444 src/libexec/database-k8s/k2hr3.config                          %{buildroot}/usr/libexec/k2hr3/database-k8s/k2hr3.config
install -D -m 444 src/libexec/database-k8s/dbaas-k2hdkc-chmpxproc-wrap.sh        %{buildroot}/usr/libexec/k2hr3/database-k8s/dbaas-k2hdkc-chmpxproc-wrap.sh
install -D -m 444 src/libexec/database-k8s/dbaas-k2hdkc.ini.templ                %{buildroot}/usr/libexec/k2hr3/database-k8s/dbaas-k2hdkc.ini.templ
install -D -m 444 src/libexec/database-k8s/dbaas-k2hdkc-ini-update.sh            %{buildroot}/usr/libexec/k2hr3/database-k8s/dbaas-k2hdkc-ini-update.sh
install -D -m 444 src/libexec/database-k8s/dbaas-k2hdkc-k2hr3-registration.sh    %{buildroot}/usr/libexec/k2hr3/database-k8s/dbaas-k2hdkc-k2hr3-registration.sh
install -D -m 444 src/libexec/database-k8s/dbaas-k2hdkc-kustomization.yaml.templ %{buildroot}/usr/libexec/k2hr3/database-k8s/dbaas-k2hdkc-kustomization.yaml.templ
install -D -m 444 src/libexec/database-k8s/dbaas-k2hdkc-serverproc-wrap.sh       %{buildroot}/usr/libexec/k2hr3/database-k8s/dbaas-k2hdkc-serverproc-wrap.sh
install -D -m 444 src/libexec/database-k8s/dbaas-k2hdkc-server.yaml.templ        %{buildroot}/usr/libexec/k2hr3/database-k8s/dbaas-k2hdkc-server.yaml.templ
install -D -m 444 src/libexec/database-k8s/dbaas-k2hdkc-slave.yaml.templ         %{buildroot}/usr/libexec/k2hr3/database-k8s/dbaas-k2hdkc-slave.yaml.templ
install -D -m 444 src/libexec/database-k8s/dbaas-k2hdkc-variables-setup.sh       %{buildroot}/usr/libexec/k2hr3/database-k8s/dbaas-k2hdkc-variables-setup.sh
install -D -m 444 src/libexec/database-k8s/k2hr3-sa.yaml.templ                   %{buildroot}/usr/libexec/k2hr3/database-k8s/k2hr3-sa.yaml.templ
install -D -m 444 src/libexec/database-k8s/k2hr3-kustomization.yaml.templ        %{buildroot}/usr/libexec/k2hr3/database-k8s/k2hr3-kustomization.yaml.templ
install -D -m 444 src/libexec/database-k8s/k2hr3-k2hr3api.yaml.templ             %{buildroot}/usr/libexec/k2hr3/database-k8s/k2hr3-k2hr3api.yaml.templ
install -D -m 444 src/libexec/database-k8s/k2hr3-k2hr3app.yaml.templ             %{buildroot}/usr/libexec/k2hr3/database-k8s/k2hr3-k2hr3app.yaml.templ
install -D -m 444 src/libexec/database-k8s/k2hr3-k2hdkc.yaml.templ               %{buildroot}/usr/libexec/k2hr3/database-k8s/k2hr3-k2hdkc.yaml.templ
install -D -m 444 src/libexec/database-k8s/k2hr3-k2hdkc.ini.templ                %{buildroot}/usr/libexec/k2hr3/database-k8s/k2hr3-k2hdkc.ini.templ
install -D -m 444 src/libexec/database-k8s/k2hr3-k2hdkc-ini-update.sh            %{buildroot}/usr/libexec/k2hr3/database-k8s/k2hr3-k2hdkc-ini-update.sh
install -D -m 444 src/libexec/database-k8s/k2hr3-api-nodeport.yaml.templ         %{buildroot}/usr/libexec/k2hr3/database-k8s/k2hr3-api-nodeport.yaml.templ
install -D -m 444 src/libexec/database-k8s/k2hr3-api-production.json.templ       %{buildroot}/usr/libexec/k2hr3/database-k8s/k2hr3-api-production.json.templ
install -D -m 444 src/libexec/database-k8s/k2hr3-api-wrap.sh                     %{buildroot}/usr/libexec/k2hr3/database-k8s/k2hr3-api-wrap.sh
install -D -m 444 src/libexec/database-k8s/k2hr3-app-nodeport.yaml.templ         %{buildroot}/usr/libexec/k2hr3/database-k8s/k2hr3-app-nodeport.yaml.templ
install -D -m 444 src/libexec/database-k8s/k2hr3-app-production.json.templ       %{buildroot}/usr/libexec/k2hr3/database-k8s/k2hr3-app-production.json.templ
install -D -m 444 src/libexec/database-k8s/k2hr3-app-wrap.sh                     %{buildroot}/usr/libexec/k2hr3/database-k8s/k2hr3-app-wrap.sh
install -D -m 444 src/libexec/database-k8s/k2hr3-app-init.sh                     %{buildroot}/usr/libexec/k2hr3/database-k8s/k2hr3-app-init.sh

%if %{make_check}
%check
%{__make} check
%endif

%files
%license COPYING
%doc README AUTHORS ChangeLog
/usr/libexec/k2hr3/database-k8s/*

%changelog
* Fri Jul 28 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.6-1
- Changed due to k2hr3cli insecure communication support - #24

* Mon Mar 06 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.5
- Updated building/packaging scripts - #22

* Thu Feb 16 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.4
- Changed CI OSs and added Alpine OS - #20
- Updated header and footer in comment lines - #19
- Updated issue/pullrequest templates and README.md - #18
- Reviewed ShellCheck processing and fixed bugs - #17
- Eliminated unnecessary copies in build_helper.sh - #16
- Updated github actions process and support os, and fixed bugs - #15
- Updated debian_build.sh for grep parameter and updated configure.ac - #14
- Updated common build scripts - #13
- Updated buld tools(Makefile.am and build_helper.sh) - #12
- Separated the shellcheck process in the build process - #11
- Updated Antpickax common scripts and tools under the buildutils directory - #10
- Enabled external customization of configure.ac and fixed for building - #9

* Tue Mar 15 2022 Takeshi Nakatani <ggtakec@gmail.com> 1.0.3
- Stabilized the startup of the k2hdkc cluster in k2hr3 - #7
- Using RockyLinux:8 instead of CentOS:8 - #6
- Fixed a bug in dbaas-k2hdkc-chmpxproc-wrap.sh - #5

* Fri Oct 29 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.2
- Removed k8soidc:jwks_uri key in k2hr3-api-production.json.templ - #3

* Thu Sep 30 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.1
- Changed passing by value to subprocess from env to option - #1

* Thu Sep 30 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.0
- First version
